Crate workers_rsx_impl

Crate workers_rsx_impl 

Macros

css
Parse CSS syntax at compile time and return it as a &'static str
html
Render a JSX-like template to an HTML string. Automatically extracts Tailwind class names and injects generated CSS as a <style> tag inside <head> (or prepended if no <head> is found).
rsx
Generate a renderable component tree without rendering it
view
Render a JSX-like template and return it as a worker::Response with HTML content type. Automatically extracts Tailwind class names and injects generated CSS as a <style> tag inside <head> (or prepended if no <head> is found).

Attribute Macros

component
Define a function component as a struct that implements Render
page
Define a page component: a #[component] that also implements From<State>.

Derive Macros

ActionJson
Derive type_tag() and json() methods for a #[serde(tag = "...")] enum.