html!() { /* proc-macro */ }Expand description
Render a JSX-like template to an HTML string.
Automatically extracts Tailwind class names and injects generated CSS as a <style> tag
inside <head> (or prepended if no <head> is found).
html!() { /* proc-macro */ }Render a JSX-like template to an HTML string.
Automatically extracts Tailwind class names and injects generated CSS as a <style> tag
inside <head> (or prepended if no <head> is found).