Render a JSX-like template to an HTML string.
Automatically extracts Tailwind class names and injects generated CSS as a <style> tag
inside <head> (or prepended if no <head> is found).
Render a JSX-like template and return it as a worker::Response with HTML content type.
Automatically extracts Tailwind class names and injects generated CSS as a <style> tag
inside <head> (or prepended if no <head> is found).